@@ -6,24 +6,25 @@ COLOR_RESET = "\x1b[0m"
 _failures = []
 _stop_on_fail = False
 
-_default_no_tb = False
 _default_max_fail = None
 _default_max_report = None
+_default_max_tb = None
 
-_no_tb = False
 _max_fail = None
 _max_report = None
+_max_tb = None
 _num_failures = 0
 
 
 def clear_failures():
     # get's called at the beginning of each test function
-    global _failures, _num_failures, _no_tb, _max_fail, _max_report
+    global _failures, _num_failures
+    global _max_fail, _max_report, _max_tb
     _failures = []
     _num_failures = 0
-    _no_tb = _default_no_tb
     _max_fail = _default_max_fail
     _max_report = _default_max_report
+    _max_tb = _default_max_tb
 
 
 def any_failures() -> bool:
@@ -45,7 +46,7 @@ def log_failure(msg="", check_str=""):
         msg = f"{msg}: {check_str}"
 
     if (_max_report is None) or (_num_failures <= _max_report):
-        if not _no_tb:
+        if _num_failures <= _max_tb:
             pseudo_trace_str = _build_pseudo_trace_str()
             msg = f"{msg}\n{pseudo_trace_str}"
 
