@@ -1,5 +1,6 @@
-from .check_log import log_failure
+import warnings
 from . import check_log
+from .check_log import log_failure
 
 _stop_on_fail = False
 
@@ -9,7 +10,7 @@ _stop_on_fail = False
 # TODO: maybe pull in extra funcitonality here instead of in plugin.py
 
 
-class CheckContextManager(object):
+class CheckContextManager:
     def __init__(self):
         self.msg = None
 
@@ -36,7 +37,10 @@ class CheckContextManager(object):
         return self
 
     def set_no_tb(self):
-        check_log._no_tb = True
+        warnings.warn(
+            "set_no_tb() is deprecated; use set_max_tb(0)", DeprecationWarning
+            )
+        check_log._max_tb = 0
 
     def set_max_fail(self, x):
         check_log._max_fail = x
@@ -44,5 +48,8 @@ class CheckContextManager(object):
     def set_max_report(self, x):
         check_log._max_report = x
 
+    def set_max_tb(self, x):
+        check_log._max_tb = x
+
 
 check = CheckContextManager()
