@@ -1,4 +1,5 @@
 import sys
+
 import pytest
 
 
@@ -9,7 +10,7 @@ def test_sequence_with_helper_funcs(pytester):
     Should show a sequence of calls
     """
     pytester.copy_example("examples/test_example_helpers.py")
-    result = pytester.runpytest()
+    result = pytester.runpytest("--check-max-tb=2")
     result.assert_outcomes(failed=1, passed=0)
     result.stdout.fnmatch_lines(
         [
@@ -22,7 +23,7 @@ def test_sequence_with_helper_funcs(pytester):
             "*in helper1() -> helper2()",
             '*in helper2() -> with check("second"):',
             "*Failed Checks: 2*",
-        ]
+        ],
     )
 
 
@@ -31,7 +32,7 @@ def test_sequence_with_helper_funcs_less_checking(pytester):
     Should show a sequence of calls
     """
     pytester.copy_example("examples/test_example_helpers.py")
-    result = pytester.runpytest()
+    result = pytester.runpytest("--check-max-tb=2")
     result.assert_outcomes(failed=1, passed=0)
     result.stdout.fnmatch_lines(
         [
@@ -44,5 +45,5 @@ def test_sequence_with_helper_funcs_less_checking(pytester):
             "*in helper1() -> helper2()",
             "*in helper2()*",
             "*Failed Checks: 2*",
-        ]
+        ],
     )
